<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Bezárás </translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Összezárás</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Kibontás</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Figyelmeztetés bezárása</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln szó</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln perc</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% a %Ln percből</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% a %Ln szóból</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Napi Előrehaladás</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Leghosszabb sorozat</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Jelenlegi sorozat</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n nap</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>A napi cél %L1%-a</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Nyelv Beállítása</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Névtelen %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Csak olvasható)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Elnézést</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nem sikerült &apos;%1&apos; mentése.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Mentés másként</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nem sikerült &apos;%1&apos; felülírása.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Fájl átnevezése</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nem sikerült &apos;%1&apos; átnevezése.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Fájl Újratöltése?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Újratölti a &apos;%1&apos; fájlt a lemezről?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Minden el nem mentett változtatás el fog veszni</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Újratöltés</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Névtelen %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Egyszerű szövegként való mentés minden formázást töröl. Töröl minden formázást?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>A fálj megváltozott</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>A &apos;%1&apos; fájlt egy másik program módosította.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Újra akarja tölteni a fájlt?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Újratöltés</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Figyelmen kívül hagyás</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Fájl törölve</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>A()z %1 fájlt egy másik program törölte</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>El szeretné menteni vagy be szeretné zárni a fájlt?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archívum megnyitása sikertelen.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Csere:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Kis- és nagybetűk közötti különbség figyelmen kívül hagyása</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Csak teljes szavakat</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Szabályos kifejezések</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Keresés felfelé</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Keresés lefelé</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Keresés...</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Csere</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Összes &amp;cseréje</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Csere</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Kicseréljünk %n előfordulást?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Elnézést</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>A keresett kifejezés nem található.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Szöveg</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Nyílt XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Formázott Szöveg Formátum</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Egyszerű Szöveg</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Minden Fájl</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Minden Támogatott Fájl</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Helyesírás-ellenőrzés...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nincsenek javaslatok)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Kép megnyitása</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Képek</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Válaszd ki az alkalmazás nyelvét:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;A rendszer nyelve&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Indítsd újra az alkalmazást, hogy a változtatások érvénybe lépjenek.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archívum megnyitása sikertelen.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statisztika</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Eszközsáv</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Helyesírás-ellenőrzés</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Szótár kiválasztása</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Elnézést</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nem sikerült a csomagfájl megnyitása.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Nincs használható szótár a csomagfájlban.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsgombok</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Egy vagy több gyorsgomb ütközik. Szeretné folytatni?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>&quot;%1&quot; szótár már létezik. Le szeretnéd cserélni?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Napi cél</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Perc:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Szó:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>A kurzor maradjon függőlegesen középen</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Blokkszerű kurzor</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Betűtípusok képének simítása</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Írógéphangok</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Intelligens idézőjelek:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dupla</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Szimpla</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Jelenetek</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Elosztó</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>A kurzor pozíciójának megjegyzése</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Szavak száma</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Oldalak száma</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Bekezdések száma</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Karakterek száma</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Karakter:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Bekezdés:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Szószámlálás algoritmusa</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Lenullázza a mai, napi előrehaladását?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Írjon byte sorrendet egyszerű szöveges fájlokba</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Alapértelmezett formátum:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Mai Lenullázása</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Előzmények</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Emlékezzen az előzményekre</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mutassa a sorozat sávokat</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimális haladás a sorozat eléréséhez:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Szóhatárok felismerése</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Karakterszám osztása hattal</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Minden betű szónak számítson</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Oldalszám Algoritmus</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stílus</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Csak ikonok</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Csak szöveg</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Szöveg az ikonok mellett</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Szöveg az ikonok alatt</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Szöveg helyzete:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Akciók</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Felfelé mozgatás</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Lefelé mozgatás</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Elválasztó hozzáadása</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Parancs</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Gyorsgomb</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akció</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Helyesírás-ellenőrzés gépelés közben</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>CSUPA NAGYBETŰS SZAVAK figyelmen kívül hagyása</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Számokat tartalmazó szavak figyelmen kívül hagyása</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Nyelv</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eltávolítás</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Saját szótár</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Eltávolítja a jelenlegi szótárat?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Felhasználói Felület</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Mindig mutassa a görgetősávot</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Mindig mutassa a felső eszköztárat</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Mindig mutassa az alsó eszköztárat</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Nem támogatott RTF fájl.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>A fájl váratlanul véget ért.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Le</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Jelenetek mozgatása felfelé</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Fel</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Jelenetek átváltása</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Jelenetek listájának mutatása (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Jelenetek listájának elrejtése (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Szűrő</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Jelenetek mozgatása lefelé</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Jelenek listájának átméretezése</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Munkamenetek kezelése</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>Munkam&amp;enetek</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikálás</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Váltás</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Új munkamenet</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Munkamenet Duplikálása</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Munkamenet átnevezése</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Töröljük a kijelölt munkamenetet?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Munkamenet neve:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Elnézést</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>A megadott munkamenet-név már használatban van.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Új...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Kezelés...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctri+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Visszaállítás alapértelmezettre</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Gyorsgomb:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Idézőjelek cseréje...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Kérlek várj</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Helyesírás-ellenőrzés</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hozzáadás</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Figyelmen kívül hagyás</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>&amp;Összes figyelmen kívül hagyása</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Változtatás</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Összes változtatása</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nincs a szótárban:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Változtatás erre:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Helyesírás ellenőrzése...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Kérlek, várj</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Folytatja a fájl ellenőrzését az elejétől?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>A helyesírás-ellenőrzés befejeződött.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Szimbólumok</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Nemrég használt szimbólumok</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Minden szimbólum</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Beszúrás</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Tömbök</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Szkriptek</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Névtelen %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Nincs kép</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Mozaikozva</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Középre igazítva</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Nyújtva</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Kicsinyítve</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Nagyítva</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Áttetszőség:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Pozíció:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Szélesség:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Szövegháttér Sarkainak Lekerekítése</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Rádiusz:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Szövegháttér Elmosása</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Szövegháttér Árnyékvetése</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Függőleges Eltolás:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margók</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Ablak:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Oldal:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Első sor behúzása</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Felette:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Alatta:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eltávolítás</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Téma Szerkesztése</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Ablak Háttere</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Szín:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Kép:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pixel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Szöveg Háttere</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Szöveg</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Betűtípus:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Helyesírási hiba:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Sorközök</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Szimpla</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 Sor</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dupla</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Arányos</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Magasság:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Bekezdésközök</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Tabulátor Szélessége:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Új Téma</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Témák</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Megnyugtató Kékség</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Régimódi</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Űr Álmok</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Íróasztal</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikálás</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Egyedi</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importálás</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Törli a &apos;%1&apos; témát?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Témák (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Téma importálása</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Téma exportálása</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Keserű Egek</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Bűbáj</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Kémjátszmák </translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Nyugalom</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Töröljük a a stoppert?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Szó:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Oldal:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Bekezdés:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Karakter:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Visszafelé</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Adott időben</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Időpont:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Emlékeztető:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nincsen futó stopper</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Stopperek</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Legutóbbiak</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Kérdés</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Félbehagyod a stopperek szerkesztését?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Témák betöltése</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Hangok betöltése</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>A FocusWriter-ről</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Egy egyszerű teljesképernyős szövegszerkesztő</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Szerzői jogvédelem alatt &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation> &lt;a href=%1&gt;GPL 3&lt;/a&gt; licensz alatt kiadva</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation> &lt;a href=%1&gt;Oxygen&lt;/a&gt; ikontémából használ ikonokat</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;LGPL 3&lt;/a&gt; licensz alatt használva</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Karakter: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Oldal: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Bekezdés: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Szó: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 megnyitása</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Névtelen %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Minden dokumentum listázása</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Váltás a következő dokumentumra</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Váltás az előző dokumentumra</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Váltás az első dokumentumra</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Váltás az utolsó dokumentumra</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Váltás a(z)  %1 dokumentumra</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Beállítások betöltése</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>A vész-gyorsítótár nem írható.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Figyelmeztetés</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>A FocusWriter hibásan lett leállítva.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Visszaállítsuk az adatokat a vész-gyorsítótárból?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Néhány fájlt nem sikerült megnyitni.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Néhány fájl csak olvasható módon lett megnyitva.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; újabb, mint a gyorsítótárazott másolata.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Felülírjuk az újabb fájlt?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Változások Mentése?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Menti a &apos;%1&apos; változásait mielőtt bezárja?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Az Ön módosításai elvesznek ha nem menti őket.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nem sikerült az írógép-hangok betöltése.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Új</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>M&amp;egnyitás...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Újratöltés &amp;</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Mentés</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Mentés m&amp;ásként...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Á&amp;tnevezés...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>&amp;Összes mentése</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Munkamenetek kezelése</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Új munkamenet</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Nyomtatás...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Be&amp;zárás</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkesztés</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Visszavonás</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Újra</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Kivágás</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Másolás</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Beillesztés</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Beillesztés &amp;Formázatlanul</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Összes kijelölése</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>&amp;Jelenet kiválasztása</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmázás</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Vastag</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Dőlt</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Aláhúzott</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Áthúzott</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Felső index</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>A&amp;lsó index</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Balra igazítás</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Középre igazítás</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>&amp;Jobbra igazítás</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Sorkizárt</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Behúzás &amp;csökkentése</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Behúzás &amp;növelése</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Bal&amp;ról jobbra blokk</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Jobbr&amp;ól balra blokk</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Eszközök</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Keresés...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>K&amp;övetkező keresése</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>&amp;Előző keresése</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Csere...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Intelligens &amp;idézőjelek</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>&amp;Dokumentum frissítése</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>&amp;Kijelölés frissítése</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Helyesírás...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>&amp;Nyelv Beállítása...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Stopperek...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>&amp;Szimbólumok</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Napi &amp;Előrehaladás</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>&amp;Eszköztár mutatása</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Menü ikonok mutatása</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Fókuszált szöveg</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Teljes &amp;képernyő</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimalizálás</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Témák...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Beállítások...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Fókusz kikapcsolása</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Egy sor fókuszálása</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Három sor fókuszálása</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Bekezdés</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Bekezdés fókuszálása</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Alkalmazás &amp;nyelve...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Néhány fájltípus nem támogatott és nem került megnyitásra.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Kikapcsolás</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Egy &amp;Sor</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Három sor</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A &amp;Qt-ról</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>&amp;Oldalbeállítás...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Címsor</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Címsor &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Címsor &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Címsor &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Címsor &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Címsor &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Címsor &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normál</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Dokumentum Intelligens Idézőjeleinek Frissítése</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Kijelölés Intelligens Idézőjeleinek Frissítése</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
